<?php

/**
 * Define the internationalization functionality
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 * @link       https://wpfiles.io
 * @since      1.0.0
 * @package    WPFiles
 * @subpackage WPFiles/includes
 */

/**
 * Define the internationalization functionality.
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 * @since      1.0.0
 * @package    WPFiles
 * @subpackage WPFiles/includes
 */
class Wp_Files_i18n {

	/**
	 * Load the plugin text domain for translation.
	 * @since    1.0.0
	 * @return void
	 */
	public function load_plugin_textdomain() {

		if (function_exists('determine_locale')) {
            $locale = determine_locale();
        } else {
            $locale = is_admin() ? get_user_locale() : get_locale();
        }
		unload_textdomain('wpfiles');
		load_textdomain('wpfiles', WP_FILES_PLUGIN_DIR . '/languages/' . $locale . '.mo');
		load_plugin_textdomain('wpfiles', false, WP_FILES_PLUGIN_DIR . '/languages/');
	}
	
	/**
	 * getTranslation
	 * @since    1.0.0
	 * @return array
	 */
	public static function getTranslation()
    {
		$settings = (array) Wp_Files_Settings::loadSettings();
		
		if(Wp_Files_Subscription::is_active($settings) && isset($settings['site_status']['website']) && is_array($settings['site_status']['website']) && $settings['site_status']['website']['was_pro'] == 1 && $settings['site_status']['is_free'] == 1 && isset($settings['site_status']['is_trial_used']) && $settings['site_status']['is_trial_used'] > 0) {
			$upgrade_now = __('Renew subscription', 'wpfiles');
			$upgrade_to_pro = __('Renew subscription', 'wpfiles');
			$unlock_new_features_sub = __('To use WPFiles folders with %s, please upgrade to a PRO plan. <a href="%s" target={"_blank"}>Click here to renew your subscription</a>.', 'wpfiles');
			$hellobar_upgrade_to_pro =  __('You\'re using WPFiles Free, to unlock more features, consider upgrading to a Pro plan. <a href="%s" target={"_blank"}>Click here to renew your subscription</a>&#160;<b>&#8594;</b>', 'wpfiles');
			$hero_section_description_one = sprintf(__('Renew your subscription to unlock all the features of the Media library along with blazing fast WPFiles built-in CDN to quickly skyrocket your website speed by optimizing your images on the fly and serving them from over %1$s locations around the globe.', 'wpfiles'), WP_FILES_CDN_POPS);
		} else if(Wp_Files_Subscription::is_active($settings) && isset($settings['site_status']['is_trial_used']) && $settings['site_status']['is_trial_used'] > 0) {	
			$upgrade_now = __('Upgrade now', 'wpfiles');
			$upgrade_to_pro = __('Upgrade to Pro', 'wpfiles');
			$unlock_new_features_sub = __('To use WPFiles folders with %s, please upgrade to a PRO plan. <a href="%s" target={"_blank"}>Click here to upgrade to Pro</a>.', 'wpfiles'); 
			$hellobar_upgrade_to_pro =  __('You\'re using WPFiles Free, to unlock more features, consider upgrading to a Pro plan. <a href="%s" target={"_blank"}>Click here to upgrade to Pro</a>&#160;<b>&#8594;</b>', 'wpfiles');
			$hero_section_description_one = sprintf(__('Upgrade to Pro to unlock all the features of the Media library along with blazing fast WPFiles built-in CDN to quickly skyrocket your website speed by optimizing your images on the fly and serving them from over %1$s locations around the globe.', 'wpfiles'), WP_FILES_CDN_POPS);
		} else {
			$upgrade_now = __('Start a free trial', 'wpfiles');
			$upgrade_to_pro = __('Start a free trial', 'wpfiles');
			$unlock_new_features_sub = __('To use WPFiles folders with %s, please upgrade to a PRO plan. <a href="%s" target={"_blank"}>Click here to start a free trial</a>.', 'wpfiles');
			$hellobar_upgrade_to_pro =  __('You\'re using WPFiles Free, to unlock more features, consider upgrading to a Pro plan. <a href="%s" target={"_blank"}>Click here to start a free trial</a>&#160;<b>&#8594;</b>', 'wpfiles');
			$hero_section_description_one = sprintf(__('Start a free trial to unlock all the features of the Media library along with blazing fast WPFiles built-in CDN to quickly skyrocket your website speed by optimizing your images on the fly and serving them from over %1$s locations around the globe.', 'wpfiles'), WP_FILES_CDN_POPS);
		}

		$translation = array(
			'all_modules'		=> __('All Modules', 'wpfiles'),
			'all_modules_description'		=> __('Extend the functionality of WPFiles with a variety of Modules.', 'wpfiles'),
			'upgrade_now'		=> $upgrade_now,
			'unsaved_changes'		=> __('Unsaved changes', 'wpfiles'),
			'save'		=> __('Save', 'wpfiles'),
			'discard'		=> __('Discard', 'wpfiles'),
			'toggle'		=> __('Toggle', 'wpfiles'),
			'all'		=> __('All', 'wpfiles'),
			'default'		=> __('Default', 'wpfiles'),
			'custom'		=> __('Custom', 'wpfiles'),
			'pro'		=> __('Pro', 'wpfiles'),
			'free'		=> __('Free', 'wpfiles'),
			'pro_plan_module'		=> __('Pro plan module', 'wpfiles'),
			'configure'		=> __('Configure', 'wpfiles'),
			'disconnect'		=> __('Disconnect', 'wpfiles'),
			'disconnect_website'		=> __('Disconnect Website', 'wpfiles'),
			'refresh_api_status'		=> __('Refresh API status', 'wpfiles'),
			'success_api_status_update'		=> __('API status update successfully', 'wpfiles'),
			'manage_website'		=> __('Manage Website', 'wpfiles'),
			'pro_module_locked_tooltip'		=> __('In order to use this module you have to upgrade to a Pro plan.', 'wpfiles'),
			'pro_feature_locked_tooltip'		=> __('In order to use this feature you have to upgrade to a Pro plan.', 'wpfiles'),
			'pro_feature_locked'		=> __('This feature is for Pro users only, to use this feature', 'wpfiles'),
			'upgrade_to_pro'		=> $upgrade_to_pro,
			'download_pro_feature_locked'		=> __('To use this feature you need to', 'wpfiles'),
			'download_and_install_pro'		=> __('download and install Pro version of WPFiles', 'wpfiles'),
			'activate'		=> __('Activate', 'wpfiles'),
			'deactivate'		=> __('Deactivate', 'wpfiles'),
			'activate_module'		=> __('Activate %s', 'wpfiles'),
			'deactivate_module'		=> __('Deactivate %s', 'wpfiles'),
			'deactivate_module_sub'		=> __('If you no longer require %s module, you can disable this module.', 'wpfiles'),
			'module_currently_disabled'		=> __('%s is currently disabled.', 'wpfiles'),
			'only_available_in_pro'		=> __('%s is only available in the Pro Plan.', 'wpfiles'),
			'module_only_available_in_pro_sub'		=> __('You need to upgrade to a Pro plan in order to use %s module. Upgrade to Pro now to get access to %s module along with tons of more	pro features and modules.', 'wpfiles'),
			'feature_only_available_in_pro_sub'		=> __('You need to upgrade to a Pro plan in order to use %s feature. Upgrade to Pro now to get access to %s feature along with tons of more	pro features and modules.', 'wpfiles'),
			'download_pro_version'		=> __('Download and install Pro version to use %s.', 'wpfiles'),
			'download_pro_version_sub'		=> __('To use Pro modules and features you need to download and install Pro version of WPFiles.', 'wpfiles'),
			'download_now'		=> __('Download now', 'wpfiles'),
			'unlock_new_features'		=> __('Unlock new features.', 'wpfiles'),
			'unlock_new_features_sub'		=> $unlock_new_features_sub,
			'folder_compression'		=> __('Folder Compression', 'wpfiles'),
			'folder_watermarking'		=> __('Folder Watermarking', 'wpfiles'),
			'in_the_free_plan_max_compression'		=> __('In the Free Plan, you can compress max %s items in one go.', 'wpfiles'),
			'in_the_free_plan_max_compression_sub'		=> __('You need to upgrade to a Pro plan in order to compress more than %s items in one go. Upgrade to Pro now to remove the max compression limit and get access to tons of more pro features and modules.', 'wpfiles'),
			'cdn'		=> __('CDN', 'wpfiles'),
			'cdn_description'		=> __('Serve images from WPFiles CDN with compression on the fly. There are over 94 edge locations in our CDN network which spans over 54 countries and 6 continents.', 'wpfiles'),
			'cdn_description'		=> sprintf(__('Serve images from WPFiles CDN with compression on the fly. There are over %1$s edge locations in our CDN network which spans over %2$s countries and %3$s continents.', 'wpfiles'), WP_FILES_CDN_POPS, "69", "6"),
			'background_images'		=> __('Background Images', 'wpfiles'),
			'background_images_sub'		=> __('Background images declared in CSS will be served from CDN as well.', 'wpfiles'),
			'background_images_explainer'		=> __('For this feature to work background images must be declared using wp_attachment functions.', 'wpfiles'),
			'compress_on_fly'		=> __('Compress On Fly', 'wpfiles'),
			'compress_on_fly_sub'		=> __('Use WPFiles CDN to automatically compress your images on the fly. No compression is done on original images.', 'wpfiles'),
			'compress_on_fly_explainer'		=> __('Compressing images on-the-fly can dramatically improve speed of web pages with images.', 'wpfiles'),
			'automatic_resizing'		=> __('Automatic Resizing', 'wpfiles'),
			'automatic_resizing_sub'		=> __('Images will be automatically resized to match container size, prevents \'properly size image\' warning in Google PageSpeed.', 'wpfiles'),
			'automatic_resizing_explainer'		=> __('This feature will fix Google PageSpeed \'Properly size images\' issues without any coding changes. No resizing is done on original	images, only those images are resized which are served from our CDN.', 'wpfiles'),
			'webp_conversion'		=> __('WebP Conversion', 'wpfiles'),
			'webp_conversion_sub'		=> __('Images will be automatically converted and served as WebP to compatible browsers.', 'wpfiles'),
			'webp_conversion_explainer'		=> __('WebP images will be automatically served to those browsers which support WebP, and for non-compatible browsers PNGs or JPEGs will be serve	', 'wpfiles'),
			'rest_api'		=> __('Rest API', 'wpfiles'),
			'rest_api_sub'		=> __('WPFiles CDN will replace image URLs when fetched via Rest API endpoints.', 'wpfiles'),
			'rest_api_explainer'		=> __('WPFiles will use rest_pre_echo_response hook to filter images in REST API responses.', 'wpfiles'),
			'purge_cache'		=> __('Purge Cache', 'wpfiles'),
			'purge_cache_sub'		=> __('Having some issues with cached CDN images? Clear cache from here.', 'wpfiles'),
			'purge_cache_explainer'		=> __('Purging cache will remove old cached images and re-index all images again into CDN.', 'wpfiles'),
			'error_cdn_suspended'		=> __('CDN is currently suspended for this website', 'wpfiles'),
			'error_cdn_inactive'		=> __('CDN is currently inactive for this website', 'wpfiles'),
			'cdn_inactive_sub'		=> __('To enable CDN module, first you need to activate CDN for <b>%s</b> from WPFiles dashboard.', 'wpfiles'),
			'cdn_suspended_sub'		=> __('To enable CDN module, first you need to get your CDN un-suspended from WPFiles dashboard.', 'wpfiles'),
			'cdn_suspended_sub_two'		=> __('Mostly CDN is suspended due to negative account balance. If your account balance is in positive and issue still persists please check you email for details or get in touch with support team.', 'wpfiles'),
			'error_cdn_deploying'		=> __('CDN is currently being deployed for this website', 'wpfiles'),
			'cdn_deploying_sub'		=> __('We\'re getting CDN up and running for <b>%s</b>. Please be patient, Get in touch with the support team if it\'s been more than a couple of hours since you\'ve activated CDN.', 'wpfiles'),
			'activate_now'		=> __('Activate now', 'wpfiles'),
			'contact_support'		=> __('Contact support', 'wpfiles'),
			'recharge_now'		=> __('Recharge now', 'wpfiles'),
			'image_compression'		=> __('Image Compression', 'wpfiles'),
			'image_compression_description'		=> __('Compress images to reduce size without the loss of quality. This will increase website speed and improve page load times.', 'wpfiles'),
			'image_sizes'		=> __('Image Sizes',	'wpfiles'),
			'image_sizes_sub'		=> __('WordPress generates multiple image thumbnails for each image you upload. Choose which of those thumbnail sizes you want to include when compressing.', 'wpfiles'),
			'included_image_sizes'		=> __('Included image sizes', 'wpfiles'),
			'automatic_compression'		=> __('Automatic Compression', 'wpfiles'),
			'automatic_compression_sub'		=> __('When you upload images to your site, WPFiles will automatically optimize and compress them for you.', 'wpfiles'),
			'automatic_compression_explainer'		=> __('Only the image sizes selected above will be automatically compressed.', 'wpfiles'),
			'super_compression'		=> __('Super Compression', 'wpfiles'),
			'super_compression_sub'		=> __('Compress images up to 2x more than regular compression with almost no visible drop in quality.', 'wpfiles'),
			'disable_wp_compression'		=> __('Disable WordPress Default Compression', 'wpfiles'),
			'disable_wp_compression_sub'		=> __('WordPress automatically compresses uploaded images by up to 90%. If these images are further compressed with WPFiles the drop in image quality is often noticeable.', 'wpfiles'),
			'convert_png_to_jpeg'		=> __('Convert PNG to JPEG', 'wpfiles'),
			'convert_png_to_jpeg_sub'		=> __('When you compress a PNG, WPFiles will check if converting it to JPEG could further reduce its size.', 'wpfiles'),
			'convert_png_to_jpeg_explainer'		=> __('Any PNGs with transparent background will be ignored. Png will be only converted if it results in a smaller size. The resulting image will have a new filename and extension (JPEG) so any hard-coded URLs on your website will need to be updated manually.', 'wpfiles'),
			'strip_exif'		=> __('Strip Image Metadata', 'wpfiles'),
			'strip_exif_sub'		=> __('Photos often store camera settings in the file, i.e., focal length, date, time and location. Removing EXIF data reduces the file size. SEO metadata is not stripped.', 'wpfiles'),
			'strip_exif_explainer'		=> __('This data adds to the size of the image. While this information might be important to photographers, it’s unnecessary for most users and safe to remove.', 'wpfiles'),
			'image_resizing'		=> __('Image Resizing', 'wpfiles'),
			'image_resizing_sub'		=> __('Detect unnecessarily large oversize images on your pages to reduce their size and decrease load times.', 'wpfiles'),
			'image_resizing_explainer'		=> __('As of WordPress 5.3, large image uploads are resized down to a specified max width and height. If you require images larger than 2560px, you can override this setting here.', 'wpfiles'),
			'image_resizing_size'		=> __('Currently your largest image size is set at max <b>%1$spx wide x %2$spx high</b>.', 'wpfiles'),
			'max_width'		=> __('Max width', 'wpfiles'),
			'max_height'		=> __('Max height', 'wpfiles'),
			'compress_original_full_size_images'		=> __('Compress Original Full-size Images', 'wpfiles'),
			'compress_original_full_size_images_sub'		=> __('Do you want WPFiles to compress the copy of original full-size image?', 'wpfiles'),
			'compress_original_full_size_images_explainer'		=> __('As of WordPress 5.3, every image that gets uploaded will have your normal thumbnail outputs, a new re-sized image, and the original upload as a backup. By default, WPFiles will only compress the thumbnail sizes your theme outputs and new re-sized image, skipping the original full-size image. Enable this setting to include optimizing this image too.', 'wpfiles'),
			'compressed_images_backup'		=> __('Compressed Images Backup', 'wpfiles'),
			'compressed_images_backup_sub'		=> __('WPFiles will store original images into a separate folder so if a image is lossy after compression you will be able to revert to original.', 'wpfiles'),
			'images_backup_explainer'		=> __('Backups will not have any negative impact on PageSpeed but it will take more space on server.', 'wpfiles'),
			'restore'		=> __('Restore', 'wpfiles'),
			'activate_image_compression'		=> __('Activate Image Compression', 'wpfiles'),
			'deactivate_image_compression'		=> __('Deactivate Image Compression', 'wpfiles'),
			'deactivate_image_compression_sub'		=> __('If you no longer require Image Compression module, you can disable this module.', 'wpfiles'),
			'image_backup_restoration'		=> __('Image Backup Restoration', 'wpfiles'),
			'image_backup_restoration_sub'		=> __('Restore images from backup in their original state.', 'wpfiles'),
			'images_restored'		=> __('images restored', 'wpfiles'),
			'number_of_images_in_backup'		=> __('%1s, you have <strong>%2s images</strong> in backup that you can restore at any point!', 'wpfiles'),
			'no_images_in_backup'		=> __('%s, you have <strong>No images</strong> in backup!', 'wpfiles'),
			'images_restored'		=> __('images restored', 'wpfiles'),
			'restoration_in_progress'		=> __('Restoration in progress', 'wpfiles'),
			'restoration_in_progress_sub'		=> __('Image restoration is in progress, you need to keep this tab open until the process completes.', 'wpfiles'),
			'start_restoration'		=> __('Start restoration', 'wpfiles'),
			'stop_restoration'		=> __('Stop restoration', 'wpfiles'),
			'attachments_that_were_watermarked'		=> __('%s watermarked images were also restored to their original state as they were also compressed, but no worries you can easily re-watermark them by using bulk watermark option in media library.', 'wpfiles'),
			'lazy_load'		=> __('Lazy Load', 'wpfiles'),
			'lazy_load_description'		=> __('Speed up your website by loading images as they scroll into view and reduce the number of images that need to be loaded on a page upfront.', 'wpfiles'),
			'media_types'		=> __('Media Types', 'wpfiles'),
			'media_types_sub'		=> __('Choose which media types you want to lazy load.', 'wpfiles'),
			'included_media_types'		=> __('Included media types', 'wpfiles'),
			'output_locations'		=> __('Output Locations', 'wpfiles'),
			'output_locations_sub'		=> __('By default WPFiles will lazy load all images, but you can refine this to specific media outputs too.', 'wpfiles'),
			'content'		=> __('Content', 'wpfiles'),
			'widgets'		=> __('Widgets', 'wpfiles'),
			'post_thumbnails'		=> __('Post Thumbnails', 'wpfiles'),
			'gravatars'		=> __('Gravatars', 'wpfiles'),
			'display_and_animation'		=> __('Display & Animation', 'wpfiles'),
			'display_and_animation_sub'		=> __('Choose how you want preloading images to be displayed, as well as how they animate into view.', 'wpfiles'),
			'fade_in'		=> __('Fade in', 'wpfiles'),
			'spinner'		=> __('Spinner', 'wpfiles'),
			'placeholder'		=> __('Placeholder', 'wpfiles'),
			'none'		=> __('None', 'wpfiles'),
			'duration'		=> __('Duration', 'wpfiles'),
			'delay'		=> __('Delay', 'wpfiles'),
			'fade_in_sub'		=> __('Once the image has loaded, choose how you want the image to display when it comes into view.', 'wpfiles'),
			'add_custom_spinner'		=> __('Add custom spinner', 'wpfiles'),
			'select'		=> __('Select', 'wpfiles'),
			'select_or_upload'		=> __('Select or upload', 'wpfiles'),
			'spinner_sub'		=> __('Display a spinner while image is lazy loading. You can choose a predefined spinner, or upload your own GIF.', 'wpfiles'),
			'add_custom_placeholder'		=> __('Add custom placeholder', 'wpfiles'),
			'change_background_for_selected_placeholder'		=> __('Change background color for selected placeholder', 'wpfiles'),
			'placeholder_sub'		=> __('Display a placeholder image while real image is lazy loading. You can choose a predefined image, or upload your own.', 'wpfiles'),
			'include_exclude'		=> __('Include/Exclude', 'wpfiles'),
			'include_exclude_sub'		=> __('Disable lazy loading for specific pages, posts or image classes.', 'wpfiles'),
			'post_types'		=> __('Post Types', 'wpfiles'),
			'post_types_sub'		=> __('Choose the post types you want to lazy load.', 'wpfiles'),
			'included_post_types'		=> __('Included post types', 'wpfiles'),
			'frontpage'		=> __('Frontpage', 'wpfiles'),
			'blog'		=> __('Blog', 'wpfiles'),
			'pages'		=> __('Pages', 'wpfiles'),
			'posts'		=> __('Posts', 'wpfiles'),
			'archives'		=> __('Archives', 'wpfiles'),
			'categories'		=> __('Categories', 'wpfiles'),
			'tags'		=> __('Tags', 'wpfiles'),
			'post_pages_urls'		=> __('Post, Pages & URLs', 'wpfiles'),
			'post_pages_urls_sub'		=> __('Add URLs to the posts and/or pages you want to disable lazy loading on.', 'wpfiles'),
			'post_pages_urls_example'		=> __('E.g. /post-slug', 'wpfiles'),
			'post_pages_urls_explainer'		=> __('Add page or post URLs one per line in relative format. I.e. <b>/page</b> or <b>/page/sub-page</b>', 'wpfiles'),
			'classes_and_ids'		=> __('Classes & IDs', 'wpfiles'),
			'classes_and_ids_sub'		=> __('Additionally, you can specify classes or IDs to avoid lazy loading. This gives you absolute control over each image on a page, not just the page itself.', 'wpfiles'),
			'classes_and_ids_example'		=> __('Add Classes or IDs one per line', 'wpfiles'),
			'classes_and_ids_explainer'		=> __('Add one class or ID per line, including the prefix. E.g <b>#image-id or .image-class</b>', 'wpfiles'),
			'scripts_location'		=> __('Scripts Location', 'wpfiles'),
			'scripts_location_sub'		=> __('By default we will load the required scripts in your footer for max performance benefits. If you are having issues, you can switch this to the header.', 'wpfiles'),
			'scripts_location_sub'		=> __('By default we will load the required scripts in your footer for max performance benefits. If you are having issues, you can switch this to the header.', 'wpfiles'),
			'footer'		=> __('Footer', 'wpfiles'),
			'footer_sub'		=> __('Your theme must be using the <b>wp_footer()</b> function.', 'wpfiles'),
			'header'		=> __('Header', 'wpfiles'),
			'header_sub'		=> __('Your theme must be using the <b>wp_head()</b> function.', 'wpfiles'),
			'native_lazyload'		=> __('Native Lazy load', 'wpfiles'),
			'native_lazyload_sub'		=> __('Enable support for native browser lazy loading.', 'wpfiles'),
			'native_lazyload_explainer'		=> __('In some cases can cause the "Defer off screen images" Google PageSpeed audit to fail. See browser compatibility <a href="%s" target={"_blank"}>here</a>.', 'wpfiles'),
			'disable_noscript'		=> __('Disable Noscript', 'wpfiles'),
			'disable_noscript_sub'		=> __('Disable NoScript while lazy loading is enabled.', 'wpfiles'),
			'disable_noscript_explainer'		=> __('Sometimes W3C HTML5 Validation may give error due to No Script.', 'wpfiles'),
			'local_webp'		=> __('Local WebP', 'wpfiles'),
			'local_webp_description'		=> __('Converts images to WebP format locally. WebPs are smaller, richer images that make sites load faster, use less data and look better.', 'wpfiles'),
			'image_watermark'		=> __('Image Watermark', 'wpfiles'),
			'image_watermark_description'		=> __('Automatically add watermark to images as they are uploaded to media library. You can also watermark existing images.', 'wpfiles'),
			'automatic_watermarking'		=> __('Automatic Watermarking', 'wpfiles'),
			'automatic_watermarking_sub'		=> __('When you upload images to your site, WPFiles will automatically watermark them for you.', 'wpfiles'),
			'watermark_type'		=> __('Watermark Type', 'wpfiles'),
			'watermark_type_sub'		=> __('Upload an image to be used as watermark or use WPFiles advanced text watermark builder.', 'wpfiles'),
			'image'		=> __('Image', 'wpfiles'),
			'image_explainer'		=> __('Selected image will be used as watermark. Size, position and other properties can be changed from below.', 'wpfiles'),
			'change_image'		=> __('Change image', 'wpfiles'),
			'upload_image'		=> __('Upload image', 'wpfiles'),
			'text'		=> __('Text', 'wpfiles'),
			'watermark_text'		=> __('Watermark text', 'wpfiles'),
			'font'		=> __('Font', 'wpfiles'),
			'font_style'		=> __('Font style', 'wpfiles'),
			'text_fill'		=> __('Text fill', 'wpfiles'),
			'text_color'		=> __('Text color', 'wpfiles'),
			'text_border_color'		=> __('Text border color', 'wpfiles'),
			'background_color'		=> __('Background color', 'wpfiles'),
			'rounded_corner'		=> __('Rounded corners', 'wpfiles'),
			'text_padding'		=> __('Text padding', 'wpfiles'),
			'text_border'		=> __('Text border', 'wpfiles'),
			'text_explainer'		=> __('Text will be used as watermark. Position, size, opacity and other properties can be changed from below.', 'wpfiles'),
			'size_position_and_opacity'		=> __('Size, Position & Opacity', 'wpfiles'),
			'size_position_and_opacity_sub'		=> __('Adjust the size, position and opacity of watermark for your images.', 'wpfiles'),
			'position'		=> __('Position', 'wpfiles'),
			'position_explainer'		=> __('Select the position where you want to display your watermark on image.', 'wpfiles'),
			'x_offset'		=> __('X-axis offset', 'wpfiles'),
			'y_offset'		=> __('Y-axis offset', 'wpfiles'),
			'size'		=> __('Size', 'wpfiles'),
			'opacity'		=> __('Opacity', 'wpfiles'),
			'watermark_images_sizes_sub'		=> __('Disable watermark for specific image sizes that you wish to prevent from watermarking.', 'wpfiles'),
			'watermarked_images_backup'		=> __('Watermarked Images Backup', 'wpfiles'),
			'watermarked_images_backup_sub'		=> __('WPFiles will store original images into a separate folder so you will be able to revert to original non-watermarked state.', 'wpfiles'),
			'attachments_that_were_compressed'		=> __('%s compressed images were also restored to their original state as they were also watermarked, but no worries you can easily re-compress them by using bulk compress option in media library.', 'wpfiles'),
			'media_download'		=> __('Media Download', 'wpfiles'),
			'media_download_description'		=> __('Download all the items from your media library or just the ones that you want. Selected items will be zipped and start downloading instantly.', 'wpfiles'),
			'folders_color'		=> __('Folders Color', 'wpfiles'),
			'folders_color_description'		=> __('Make your folders stand out from the crowd by applying colors to them. Because different folders will be used for different purposes.', 'wpfiles'),
			'colors'		=> __('Colors', 'wpfiles'),
			'colors_sub'		=> __('Modify or add new colors for your folders.', 'wpfiles'),
			'add_new_color'		=> __('Add new color', 'wpfiles'),
			'starred_media_folder'		=> __('Starred Media & Folders', 'wpfiles'),
			'starred_media_folder_description'		=> __('Starring is a way to bookmark your important media or folders. This allows you to quickly access your most important media or folders at all times.', 'wpfiles'),
			'star_folders'		=> __('Star Folders', 'wpfiles'),
			'star_folders_sub'		=> __('Allow folders to be starred or not.', 'wpfiles'),
			'star_media'		=> __('Star Media', 'wpfiles'),
			'star_media_sub'		=> __('Allow Media to be starred or not.', 'wpfiles'),
			'trash_bin'		=> __('Trash Bin', 'wpfiles'),
			'trash_bin_description'		=> __('The trash bin is temporary storage for media or folders set aside for deletion. In case something happens, they can be restored.', 'wpfiles'),
			'auto_delete_old_items'		=> __('Auto Delete Old Items', 'wpfiles'),
			'auto_delete_old_items_sub'		=> __('Media and Folders will be permanently deleted automatically from trash bin after a specified period of time.', 'wpfiles'),
			'auto_delete_old_items_explainer'		=> __('WPFiles will automatically delete items older than <b>%s days</b> from trash bin. This will affect all other trashed items as well such as posts and pages.', 'wpfiles'),
			'days'		=> __('days', 'wpfiles'),
			'attachments_upon_folder_deletion'		=> __('Attachments Upon Folder Deletion', 'wpfiles'),
			'attachments_upon_folder_deletion_sub'		=> __('When a folder filled with attachments/media is deleted what should happen to those attachments inside?', 'wpfiles'),
			'move_to_trash_bin'		=> __('Move to Trash Bin', 'wpfiles'),
			'move_to_uncategorized'		=> __('Move to Uncategorized', 'wpfiles'),
			'woocommerce_folders'		=> __('WooCommerce Folders', 'wpfiles'),
			'wooCommerce_folders_description'		=> __('Organize all of your WooCommerce product images into folders automatically created on basis of products, categories, and more.', 'wpfiles'),
			'sub_folders_creation'		=> __('Sub Folders Creation', 'wpfiles'),
			'sub_folders_creation_sub'		=> __('Sub folders will be created to categorize products in their respective categories.', 'wpfiles'),
			'sub_folders_creation_explainer'		=> __('Choose how you want to name your automatically sub folders.', 'wpfiles'),
			'based_on_category_name'		=> __('Based on Category Name', 'wpfiles'),
			'based_on_category_slug'		=> __('Based on Category Slug', 'wpfiles'),
			'based_on_category_id'		=> __('Based on Category ID #', 'wpfiles'),
			'gutenberg_gallery'		=> __('Gutenberg Gallery', 'wpfiles'),
			'gutenberg_gallery_description'		=> __('Create dynamic galleries from a folder. Show images in columns, set the maximum number of images per column, choose the layout, and much more.', 'wpfiles'),
			'third_party_compatibility'		=> __('3rd Party Compatibility', 'wpfiles'),
			'third_party_gutenberg'		=> __('Gutenberg', 'wpfiles'),
			'third_party_elementor'		=> __('Elementor', 'wpfiles'),
			'third_party_beaver_builder'		=> __('Beaver Builder', 'wpfiles'),
			'third_party_brizy_builder'		=> __('Brizy Builder', 'wpfiles'),
			'third_party_cornerstone_builder'		=> __('Cornerstone Builder', 'wpfiles'),
			'third_party_divi_builder'		=> __('Divi Builder', 'wpfiles'),
			'third_party_thrive_quiz_builder'		=> __('Thrive Quiz Builder', 'wpfiles'),
			'third_party_fusion_builder'		=> __('Fusion Builder', 'wpfiles'),
			'third_party_oxygen_builder'		=> __('Oxygen Builder', 'wpfiles'),
			'third_party_tatsu_builder'		=> __('Tatsu Builder', 'wpfiles'),
			'third_party_dokan'		=> __('Dokan', 'wpfiles'),
			'third_party_woocommerce'		=> __('WooCommerce', 'wpfiles'),
			'third_party_class_editor'		=> __('Classic Editor', 'wpfiles'),
			'third_party_compatibility_description'		=> __('Directly integrate WPFiles into over 20+ plugins and themes. This means that you can now have WPFiles media library management everywhere.', 'wpfiles'),
			'third_party_support'		=> __('%s Support', 'wpfiles'),
			'third_party_support_sub'		=> __('Integrate WPFiles folders structure directly into %s.', 'wpfiles'),
			'general_settings'		=> __('General Settings', 'wpfiles'),
			'general_settings_description'		=> __('In this section, you will find all generic settings related to WPFiles.', 'wpfiles'),
			'media_settings'		=> __('Media Settings', 'wpfiles'),
			'media_settings_description'		=> __('In this section, you will find all settings related to the media library.', 'wpfiles'),
			'import_export'		=> __('Import & Export', 'wpfiles'),
			'import_export_description'		=> __('In this section, you will find all settings related to importing and exporting data.', 'wpfiles'),
			'database_tools'		=> __('Database Tools', 'wpfiles'),
			'database_tools_description'		=> __('In this section, you will find all settings related to database and API.', 'wpfiles'),
			'system_status'		=> __('System Status', 'wpfiles'),
			'system_status_description'		=> __('Monitor your system\'s status and see the details of key components.', 'wpfiles'),
			'maximum_file_upload_size'		=> __('Max File Upload Size', 'wpfiles'),
			'maximum_file_upload_size_sub'		=> __('Configure maximum file upload size allowed by media library.', 'wpfiles'),
			'maximum_file_size'		=> __('Max file size', 'wpfiles'),
			'allowed_file_types'		=> __('Allowed File Types', 'wpfiles'),
			'allowed_file_types_sub'		=> __('If a specific file type is restricted by media library you can add that file type into allowed list here.', 'wpfiles'),
			'column_name'		=> __('Column Name', 'wpfiles'),
			'description'		=> __('Description', 'wpfiles'),
			'mime_type'		=> __('MIME Type', 'wpfiles'),
			'extension'		=> __('Extension', 'wpfiles'),
			'active'		=> __('Active', 'wpfiles'),
			'add_custom_file_types'		=> __('Add custom file types', 'wpfiles'),
			'file_description'		=> __('File Description', 'wpfiles'),
			'add'		=> __('Add', 'wpfiles'),
			'media_list_columns'		=> __('Media List Columns', 'wpfiles'),
			'media_list_columns_sub'		=> __('Manage and organize columns in the media list.', 'wpfiles'),
			'plugin_language'		=> __('WPFiles Language', 'wpfiles'),
			'plugin_language_sub'		=> __('By default, WPFiles will use the language you\'d set in <a href="%s" target={"_blank"}>Wordpress Admin Settings</a> if a matching translation is available.', 'wpfiles'),
			'wordpress_default'		=> __('WordPress Default', 'wpfiles'),
			'restrict_settings_access'		=> __('Restrict Settings Access', 'wpfiles'),
			'restrict_settings_access_sub'		=> __('If enabled, only users with admin role will have access to WPFiles setting and modules pages.', 'wpfiles'),
			'auto_update_wpfiles'		=> __('Auto Update WPFiles', 'wpfiles'),
			'auto_update_wpfiles_sub'		=> __('Plugin will be automatically updated to the latest version.', 'wpfiles'),
			'usage_tracking'		=> __('Usage Tracking', 'wpfiles'),
			'usage_tracking_sub'		=> __('Help us make your experience with WPFiles better by allowing us to collect non-sensitive usage data.', 'wpfiles'),
			'plugin_settings_and_folders'		=> __('WPFiles Settings & Folders', 'wpfiles'),
			'plugin_settings_and_folders_sub'		=> __('Import/Export your WPFiles settings and folders, This option is useful for replicating WPFiles settings across multiple websites.', 'wpfiles'),
			'import'		=> __('Import', 'wpfiles'),
			'export'		=> __('Export', 'wpfiles'),
			'settings_file'		=> __('Settings file', 'wpfiles'),
			'settings_file_explainer'		=> __('Import settings by locating settings file and clicking "%s".', 'wpfiles'),
			'plugin_settings'		=> __('Plugin settings', 'wpfiles'),
			'plugin_folders'		=> __('Folders', 'wpfiles'),
			'error_invalid_import_file'		=> __('Invalid file type! Only .XML file type is allowed', 'wpfiles'),
			'error_please_upload_file'		=> __('Please upload setting file', 'wpfiles'),
			'import_now'		=> __('Import now', 'wpfiles'),
			'export_now'		=> __('Export now', 'wpfiles'),
			'other_plugins'		=> __('Other Plugins', 'wpfiles'),
			'other_plugins_sub'		=> __('If you were using another plugin to manage media for your website before switching to WPFiles, you can import the settings and data from those plugins here.', 'wpfiles'),
			'clean_data'		=> __('Clean Data', 'wpfiles'),
			'import_data'		=> __('Import Data', 'wpfiles'),
			'other_plugin_details'		=> __('%1s <span>By %2s</span>', 'wpfiles'),
			'other_plugin_details_sub'		=> __('We found you have <strong>(%1s)</strong> folders you created with <strong>%2s</strong> plugin.', 'wpfiles'),
			'no_plugin_detected'		=> __('No plugin detected with importable data.', 'wpfiles'),
			'update_api_status'		=> __('Update API Status', 'wpfiles'),
			'update_api_status_sub'		=> __('If you are having issue with enabling pro features you can force the API to update your subscription status here.', 'wpfiles'),
			'forcefully_update_api_status'		=> __('Forcefully update API status', 'wpfiles'),
			'recreate_missing_tables'		=> __('Re-create missing database tables', 'wpfiles'),
			'recreate_missing_tables_sub'		=> __('Check if required tables exist and create them if not.', 'wpfiles'),
			'recreate_missing_tables'		=> __('Re-create Missing Database Tables', 'wpfiles'),
			'recreate_missing_tables_sub'		=> __('Check if required tables exist and create them if not.', 'wpfiles'),
			'recreate_tables'		=> __('Re-create tables', 'wpfiles'),
			'delete_plugin_data'		=> __('Delete WPFiles Data Upon Plugin Removal', 'wpfiles'),
			'delete_plugin_data_sub'		=> __('Remove all WPFiles data on uninstall.', 'wpfiles'),
			'delete_plugin_data_explainer'		=> __('When you uninstall the plugin, what do you want to do with your settings, folders and all other data relating to WPFiles? You can save them for next time, or wipe them back to factory settings.', 'wpfiles'),
			'are_you_sure_you_want_to_reset_factory_settings'		=> __('Are you sure you want to reset default settings?', 'wpfiles'),
			'manual_data_removal'		=> __('Manual WPFiles Data Removal', 'wpfiles'),
			'manual_data_removal_sub'		=> __('Wipe all data and reset to default factory settings.', 'wpfiles'),
			'manual_data_removal_explainer'		=> __('Proceed with caution, factory reset will wipe out all settings, media folders, modules and connected account, this action is irreversible.', 'wpfiles'),
			'reset_factory_settings'		=> __('Reset factory settings', 'wpfiles'),
			'copy_site_info'		=> __('Copy site info to clipboard', 'wpfiles'),
			'success_copied_to_clipboard'		=> __('Successfully copied to clipboard', 'wpfiles'),
			'currently_active'		=> __('Currently active', 'wpfiles'),
			'account_connection_required'		=> __('WPFiles account connection is required.', 'wpfiles'),
			'connect_account_to_use_module'		=> __('You need to connect you website with your WPFiles account in order to use %1s module. If you aren\'t already registered <a href="%2s" target={"_blank"}>click here to register now</a>, it\'s free.', 'wpfiles'),
			'connect_account'		=> __('Connect account', 'wpfiles'),
			'connect_now'		=> __('Connect now', 'wpfiles'),
			'connect_wpfiles_account'		=> __('Connect WPFiles account', 'wpfiles'),
			'do_not_have_account_register_now'		=> __('Don\'t have account? <a href="%s" target={"_blank"}>Register now</a>', 'wpfiles'),
			'secure'		=> __('secure', 'wpfiles'),
			'bandwidth_used'		=> __('In last 30 days', 'wpfiles'),
			'bandwidth_amount_used'		=> __('%s used', 'wpfiles'),
			'cdn_is_currently'		=> __('CDN is currently', 'wpfiles'),
			'deploying'		=> __('Deploying', 'wpfiles'),
			'suspended'		=> __('Suspended', 'wpfiles'),
			'inactive'		=> __('Inactive', 'wpfiles'),
			'stats'		=> __('Stats', 'wpfiles'),
			'unlock_plugin_support'		=> __('Unlock %s Support', 'wpfiles'),
			'unlock_plugin_support_sub'		=> __('To use WPFiles folders with %s, please upgrade to PRO version.', 'wpfiles'),
			'sidebar_upgrade_to_pro_sub'		=> __('Unlock true potential of WPFiles, Image compression, CDN, watermark and more...', 'wpfiles'),
			'sidebar_join_fb_group'		=> __('Join Private FB Group', 'wpfiles'),
			'sidebar_join_fb_group_sub'		=> __('Discussions, questions, tutorials, sneak peaks, and exclusive giveaways.', 'wpfiles'),
			'sidebar_youtube_channel'		=> __('WPFiles YouTube Channel', 'wpfiles'),
			'sidebar_youtube_channel_sub'		=> __('Take a visual dive into everything WPFiles has to offer.', 'wpfiles'),
			'sidebar_helpful_docs'		=> __('Helpful Docs', 'wpfiles'),
			'sidebar_helpful_docs_sub'		=> __('Browse through helpful tutorials/articles to better understand WPFiles.', 'wpfiles'),
			'sidebar_ticket_support'		=> __('Ticket Support', 'wpfiles'),
			'sidebar_ticket_support_sub'		=> __('Get direct help quickly from our qualified support team.', 'wpfiles'),
			'sidebar_suggest_a_feature'		=> __('Suggest a Feature', 'wpfiles'),
			'sidebar_suggest_a_feature_sub'		=> __('Got an idea or suggestion for WPFiles? we would love to hear it.', 'wpfiles'),
			'sidebar_affiliate_program'		=> __('Affiliate Program', 'wpfiles'),
			'sidebar_affiliate_program_sub'		=> __('Start promoting WPFiles and earn flat %s from each sale.', 'wpfiles'),
			'let_us_help_you'		=> __('Let us help you', 'wpfiles'),
			'let_us_help_you_sub'		=> __('Hey %s, Would you like to unlock the full potential of your WPFiles? We created a really short course consisting of 5 emails only (1 email/day) packed with resources for website speed optimization, media management and much more - just for you!', 'wpfiles'),
			'enter_your_email'		=> __('Enter your email...', 'wpfiles'),
			'send_me'		=> __('Send me', 'wpfiles'),
			'no_spam'		=> __('WPFiles respect your privacy. No Spam!', 'wpfiles'),
			'success_email_verified'		=> __('Email verified successfully', 'wpfiles'),
			'installer_getting_started'		=> __('Getting started', 'wpfiles'),
			'installer_import_data'		=> __('Import data', 'wpfiles'),
			'installer_connect_account'		=> __('Connect account', 'wpfiles'),
			'installer_free_course'		=> __('Free Course', 'wpfiles'),
			'installer_usage_tracking'		=> __('Usage tracking', 'wpfiles'),
			'installer_ready'		=> __('Ready', 'wpfiles'),
			'welcome_to_installer'		=> __('Welcome to WPFiles setup wizard!', 'wpfiles'),
			'welcome_to_installer_sub'		=> __('Thanks for installing WPFiles. You are going to be rocking out with your new media library in no time. To get started, we\'ll walk you through a few simple steps. It\'s easy as 1-2-3 ', 'wpfiles'),
			'lets_get_started'		=> __('Let\'s get started', 'wpfiles'),
			'import_from_other_plugins'		=> __('Import Data from other Media Library Plugins.', 'wpfiles'),
			'back'		=> __('Back', 'wpfiles'),
			'skip_step'		=> __('Skip this step', 'wpfiles'),
			'continue'		=> __('Continue', 'wpfiles'),
			'allow_and_continue'		=> __('Allow & Continue', 'wpfiles'),
			'connect_your_wpfiles_account'		=> __('Connect your WPFiles Account.', 'wpfiles'),
			'connect_your_wpfiles_account_sub'		=> __('In order to use some of the features such as Image Compression, you will need to connect your website to a WPFiles account. Click on the button below to connect. If you do not have a WPFiles account simply <a href="%s" target={"_blank"}>click here to register</a>. It\'s free, quick easy, and secure.', 'wpfiles'),
			'disconnect_account'		=> __('Disconnect account', 'wpfiles'),
			'sign_up_for_email_course'		=> __('Sign up for our 5 part short email course.', 'wpfiles'),
			'signed_up_for_email_course'		=> __('Great! You are now signed-up for the course.', 'wpfiles'),
			'signed_up_for_email_course_sub'		=> __('All you have to do now is keep an eye on your inbox for a daily email from WPFiles.', 'wpfiles'),
			'help_us_usage_tracking'		=> __('Help us to make your WPFiles experience better.', 'wpfiles'),
			'help_us_usage_tracking_sub'		=> __('%s, in order to make your WPFiles experience better and secure we need to collect some non-sensitive usage data.', 'wpfiles'),
			'what_permissions_are_being_granted'		=> __('What permissions are being granted?', 'wpfiles'),
			'your_profile_overview'		=> __('Your profile overview', 'wpfiles'),
			'your_profile_overview_sub'		=> __('Name, email and geo.', 'wpfiles'),
			'your_site_overview'		=> __('Your site overview', 'wpfiles'),
			'your_site_overview_sub'		=> __('Site address, WordPress version and tech stack.', 'wpfiles'),
			'current_plugins_events'		=> __('Current plugins events', 'wpfiles'),
			'current_plugins_events_sub'		=> __('Activation, deactivation and uninstall.', 'wpfiles'),
			'congratulations_your_wpfiles_is_ready_now'		=> __('Congratulations, your WPFiles is ready now!', 'wpfiles'),
			'congratulations_your_wpfiles_is_ready_now_sub'		=> __('Make sure to <a href="%1s" target={"_blank"}>subscribe WPFiles on YouTube</a> and <a href="%2s" target={"_blank"}>Join Private FB Group</a> for discussions, questions, tutorials, sneak peaks, and exclusive giveaways.', 'wpfiles'),
			'goto_modules'		=> __('Goto modules', 'wpfiles'),
			'goto_settings'		=> __('Goto settings', 'wpfiles'),
			'goto_library'		=> __('Goto media library', 'wpfiles'),
			'click_here_to_skip_installation'		=> __('Click here to skip installation (Not Recommended)', 'wpfiles'),
			'are_you_sure_to_want_to_skip_installation'		=> __('Are you sure to want to skip installation?', 'wpfiles'),
			'are_you_sure_to_want_to_skip_installation_sub'		=> __('We highly recommend you not skip installation. The installer will guide you through each important step to get familiar with WPFiles and all the settings. It will hardly take a few minutes.', 'wpfiles'),
			'media_library'		=> __('Media Library', 'wpfiles'),
			'new'		=> __('New', 'wpfiles'),
			'file_upload'		=> __('File Upload', 'wpfiles'),
			'folder_upload'		=> __('Folder Upload', 'wpfiles'),
			'did_you_know'		=> __('Did you know? ', 'wpfiles'),
			'dailytip_1'		=> __('You can use WPFiles to watermark your images.', 'wpfiles'),
			'dailytip_2'		=> __('You can use WPFiles CDN to compress and serve WebP images on the go.', 'wpfiles'),
			'dailytip_3'		=> __('You can use WPFiles CDN to speed up your website.', 'wpfiles'),
			'dailytip_4'		=> __('You can use WPFiles to automatically organize WooCommerce product images.', 'wpfiles'),
			'dailytip_5'		=> __('You can use WPFiles to bulk watermark & compress your directory images as well.', 'wpfiles'),
			'turn_off_daily_tips'		=> __('Turn off daily tips', 'wpfiles'),
			'turn_off_daily_tips_sub'		=> __('We know that it\'s easy to get overwhelmed by all the features we have in WPFiles, That\'s why we\'ve compiled daily tips on different features and modules to help you unlock true potential of WPFiles. If you want you can turn them off for a specific period of time too.', 'wpfiles'),
			'turn_off_daily_tips_for'		=> __('Turn off daily tips for', 'wpfiles'),
			'do_not_turn_off'		=> __('Don\'t turn off', 'wpfiles'),
			'one_week'		=> __('One week', 'wpfiles'),
			'two_weeks'		=> __('Two weeks', 'wpfiles'),
			'one_month'		=> __('One month', 'wpfiles'),
			'three_months'		=> __('Three months', 'wpfiles'),
			'permanently_turn_off'		=> __('Permanently turn off', 'wpfiles'),
			'folders'		=> __('Folders', 'wpfiles'),
			'files'		=> __('Files', 'wpfiles'),
			'all_files'		=> __('All Files', 'wpfiles'),
			'root'		=> __('Root', 'wpfiles'),
			'uncategorized'		=> __('Uncategorized', 'wpfiles'),
			'starred'		=> __('Starred', 'wpfiles'),
			'trashed'		=> __('Trashed', 'wpfiles'),
			'all_folders'		=> __('All Folders', 'wpfiles'),
			'select_folder'		=> __('Select Folder', 'wpfiles'),
			'folders_search'		=> __('Folders search', 'wpfiles'),
			'search_folders_placeholder'		=> __('Search folders...', 'wpfiles'),
			'search_media_placeholder'		=> __('Search media...', 'wpfiles'),
			'folder_name_placeholder'		=> __('Folder name...', 'wpfiles'),
			'filter'		=> __('Filter', 'wpfiles'),
			'no'		=> __('No', 'wpfiles'),
			'folder_selected'		=> __('folder selected', 'wpfiles'),
			'folders_selected'		=> __('folders selected', 'wpfiles'),
			'item_selected'		=> __('item selected', 'wpfiles'),
			'items_selected'		=> __('items selected', 'wpfiles'),
			'watermark'		=> __('Watermark', 'wpfiles'),
			'compress'		=> __('Compress', 'wpfiles'),
			'compression'		=> __('Compression', 'wpfiles'),
			'upgrade'		=> __('Upgrade', 'wpfiles'),
			'go_pro'		=> __('Go Pro', 'wpfiles'),
			'name'		=> __('Name', 'wpfiles'),
			'author'		=> __('Author', 'wpfiles'),
			'upload_to'		=> __('Upload to', 'wpfiles'),
			'title'		=> __('Title', 'wpfiles'),
			'date'		=> __('Date', 'wpfiles'),
			'type'		=> __('Type', 'wpfiles'),
			'status'		=> __('Status', 'wpfiles'),
			'attach'		=> __('Attach', 'wpfiles'),
			'un_attach'		=> __('Un-attach', 'wpfiles'),
			'unattached'		=> __('Unattached', 'wpfiles'),
			'add_to'		=> __('Add to', 'wpfiles'),
			'move_to'		=> __('Move to', 'wpfiles'),
			'download'		=> __('Download', 'wpfiles'),
			'delete'		=> __('Delete', 'wpfiles'),
			'restore'		=> __('Restore', 'wpfiles'),
			'delete_forever'		=> __('Delete forever', 'wpfiles'),
			'cancel'		=> __('Cancel', 'wpfiles'),
			'new_folder'		=> __('New Folder', 'wpfiles'),
			'remove_from_starred'		=> __('Remove from starred', 'wpfiles'),
			'add_to_starred'		=> __('Add to Starred', 'wpfiles'),
			'goto_item_location'		=> __('Goto item location', 'wpfiles'),
			'cut'		=> __('Cut', 'wpfiles'),
			'paste'		=> __('Paste', 'wpfiles'),
			'rename'		=> __('Rename', 'wpfiles'),
			'shortcut'		=> __('Shortcut', 'wpfiles'),
			'create_a_shortcut'		=> __('Create a shortcut', 'wpfiles'),
			'folder_color'		=> __('Folder color', 'wpfiles'),
			'remove_folder_color'		=> __('Remove folder color', 'wpfiles'),
			'item_and_other'		=> __('%1s and %2s other', 'wpfiles'),
			'item_and_others'		=> __('%1s and %2s others', 'wpfiles'),
			'folders_sorting'		=> __('Folders sorting', 'wpfiles'),
			'media_sorting'		=> __('Media sorting', 'wpfiles'),
			'sort_by_ascending'		=> __('Sort by Ascending', 'wpfiles'),
			'sort_by_descending'		=> __('Sort by Descending', 'wpfiles'),
			'all_dates'		=> __('All dates', 'wpfiles'),
			'all_media_items'		=> __('All media items', 'wpfiles'),
			'mine'		=> __('Mine', 'wpfiles'),
			'sort_by_name'		=> __('Sort by Name', 'wpfiles'),
			'sort_by_date'		=> __('Sort by Date', 'wpfiles'),
			'sort_by_date_modified'		=> __('Sort by Date Modified', 'wpfiles'),
			'sort_by_author'		=> __('Sort by Author', 'wpfiles'),
			'filter_by_months'		=> __('Filter by Months', 'wpfiles'),
			'filter_by_type'		=> __('Filter by Type', 'wpfiles'),
			'filter_by_type'		=> __('Filter by Type', 'wpfiles'),
			'reset'		=> __('Reset', 'wpfiles'),
			'bulk_select_items'		=> __('Bulk Select Items', 'wpfiles'),
			'bulk_select_folders'		=> __('Bulk Select Folders', 'wpfiles'),
			'select_destination_for'		=> __('Select destination for', 'wpfiles'),
			'number_selected_item'		=> __('%s selected item', 'wpfiles'),
			'number_selected_items'		=> __('%s selected items', 'wpfiles'),
			'move_here'		=> __('Move here', 'wpfiles'),
			'attach_to_existing_content'		=> __('Attach to existing content', 'wpfiles'),
			'close_media_attachment_panel'		=> __('Close media attachment panel', 'wpfiles'),
			'items_older_than_will_be_deleted'		=> sprintf(__('Items older than %s days will be automatically deleted.', 'wpfiles'), EMPTY_TRASH_DAYS ? EMPTY_TRASH_DAYS : 30),
			'empty_bin'		=> __('Empty bin', 'wpfiles'),
			'uploading_item'		=> __('Uploading %s item', 'wpfiles'),
			'uploading_items'		=> __('Uploading %s items', 'wpfiles'),
			'item_was_uploaded'		=> __('%s item was uploaded', 'wpfiles'),
			'items_were_uploaded'		=> __('%s items were uploaded', 'wpfiles'),
			'and_item_failed'		=> __('and %s item failed', 'wpfiles'),
			'and_items_failed'		=> __('and %s items failed', 'wpfiles'),
			'item_was_uploaded_successfully'		=> __('%s item was uploaded successfully', 'wpfiles'),
			'items_were_uploaded_successfully'		=> __('%s items were uploaded successfully', 'wpfiles'),
			'processing'		=> __('Processing...', 'wpfiles'),
			'uploaded_successfully'		=> __('Uploaded successfully', 'wpfiles'),
			'upload_failed_try_again'		=> __('Upload failed. Try again', 'wpfiles'),
			'item_failed_to_upload'		=> __('%s item failed to upload', 'wpfiles'),
			'items_failed_to_upload'		=> __('%s items failed to upload', 'wpfiles'),
			'upload_pending'		=> __('Upload pending', 'wpfiles'),
			'starting_upload'		=> __('Starting upload...', 'wpfiles'),
			'upload_complete'		=> __('Upload complete', 'wpfiles'),
			'compression_pending'		=> __('Compression pending', 'wpfiles'),
			'starting_compression'		=> __('Starting compression...', 'wpfiles'),
			'compression_complete'		=> __('Compression complete', 'wpfiles'),
			'watermark_pending'		=> __('Watermark pending', 'wpfiles'),
			'starting_watermark'		=> __('Starting watermark...', 'wpfiles'),
			'watermark_complete'		=> __('Watermark complete', 'wpfiles'),
			'percent_out_of'		=> __('%1s (%2s out of %3s)', 'wpfiles'),
			'total_size'		=> __('Total size: %s', 'wpfiles'),
			'processing_in_progress'		=> __('Processing…', 'wpfiles'),
			'compressing_item'		=> __('Compressing %s item', 'wpfiles'),
			'compressing_items'		=> __('Compressing %s items', 'wpfiles'),
			'item_was_compressed'		=> __('%s item was compressed', 'wpfiles'),
			'items_were_compressed'		=> __('%s items were compressed', 'wpfiles'),
			'item_was_compressed_successfully'		=> __('%s item was compressed successfully', 'wpfiles'),
			'items_were_compressed_successfully'		=> __('%s items were compressed successfully', 'wpfiles'),
			'item_failed_to_compress'		=> __('%s item failed to compress', 'wpfiles'),
			'items_failed_to_compress'		=> __('%s items failed to compress', 'wpfiles'),
			'watermarking_item'		=> __('Watermarking %s item', 'wpfiles'),
			'watermarking_items'		=> __('Watermarking %s items', 'wpfiles'),
			'item_was_watermarked'		=> __('%s item was watermarked', 'wpfiles'),
			'items_were_watermarked'		=> __('%s items were watermarked', 'wpfiles'),
			'item_was_watermarked_successfully'		=> __('%s item was watermarked successfully', 'wpfiles'),
			'items_were_watermarked_successfully'		=> __('%s items were watermarked successfully', 'wpfiles'),
			'item_failed_to_watermark'		=> __('%s item failed to watermark', 'wpfiles'),
			'items_failed_to_watermark'		=> __('%s items failed to watermark', 'wpfiles'),
			'error_folder_no_media_items'		=> __('Folder have no media items', 'wpfiles'),
			'error_enter_folder_name'		=> __('Please enter a valid folder name', 'wpfiles'),
			'drop_files_to_upload_them'		=> __('Drop files to upload them instantly to:', 'wpfiles'),
			'of_disk_space_saved'		=> __('of disk space saved', 'wpfiles'),
			'of_bandwidth_saved'		=> __('of bandwidth saved', 'wpfiles'),
			'image_compressed'		=> __('image compressed', 'wpfiles'),
			'images_compressed'		=> __('images compressed', 'wpfiles'),
			'bulk_compression'		=> __('Bulk compression', 'wpfiles'),
			'directory_compression'		=> __('Directory compression', 'wpfiles'),
			'compression_in_progress'		=> __('Compression in progress', 'wpfiles'),
			'compression_in_progress_sub'		=> __('Bulk Compression is in progress, you need to keep this tab open until the process completes.', 'wpfiles'),
			'compression_in_progress_looking'		=> __('looking for images to compress', 'wpfiles'),
			'compression_in_progress_looking_sub'		=> __('WPFiles is looking for images to compress, you need to keep this tab open until the process completes.', 'wpfiles'),
			'stop_compression'		=> __('Stop compression', 'wpfiles'),
			're_check_images'		=> __('Re-check images', 'wpfiles'),
			'start_bulk_compression'		=> __('Start bulk compression', 'wpfiles'),
			'image_watermarked'		=> __('image watermarked', 'wpfiles'),
			'images_watermarked'		=> __('images watermarked', 'wpfiles'),
			'watermarking_in_progress'		=> __('Watermarking in progress', 'wpfiles'),
			'watermarking_in_progress_sub'		=> __('Bulk Watermarking is in progress, you need to keep this tab open until the process completes.', 'wpfiles'),
			'watermarking_in_progress_looking'		=> __('looking for images to watermark', 'wpfiles'),
			'watermarking_in_progress_looking_sub'		=> __('WPFiles is looking for images to watermark, you need to keep this tab open until the process completes.', 'wpfiles'),
			'watermark_image_not_exist'		=> __('Watermark is not yet configured! Please set watermark first', 'wpfiles'),
			'stop_watermarking'		=> __('Stop watermarking', 'wpfiles'),
			'start_bulk_watermarking'		=> __('Start bulk watermarking', 'wpfiles'),
			'are_you_sure'		=> __('Are you sure?', 'wpfiles'),
			'are_you_sure_you_want_to_delete_item'		=> __('Are you sure you want to delete %s selected item?', 'wpfiles'),
			'are_you_sure_you_want_to_delete_items'		=> __('Are you sure you want to delete %s selected items?', 'wpfiles'),
			'are_you_sure_you_want_to_delete_permanently_item'		=> __('Are you sure you want to permanently delete %s selected item?', 'wpfiles'),
			'are_you_sure_you_want_to_delete_permanently_items'		=> __('Are you sure you want to permanently delete %s selected items?', 'wpfiles'),
			'are_you_sure_you_want_to_delete_permanently_in_bin'		=> __('Are you sure you want to permanently delete all the items in the Bin?', 'wpfiles'),
			'you_have_not_selected_folder_file_yet'		=> __('You have not selected any folder/file yet.', 'wpfiles'),
			'add_item_to_a_new_folder'		=> __('Add %s selected item to a new folder', 'wpfiles'),
			'add_items_to_a_new_folder'		=> __('Add %s selected items to a new folder', 'wpfiles'),
			'add_items_to_a_new_folder_description'		=> __('A new folder will be created, and all the selected items will be moved into that folder.', 'wpfiles'),
			'create_and_move'		=> __('Create and move', 'wpfiles'),
			'are_you_sure_you_want_to_restore_item'		=> __('Are you sure you want to restore %s selected item?', 'wpfiles'),
			'are_you_sure_you_want_to_restore_items'		=> __('Are you sure you want to restore %s selected items?', 'wpfiles'),
			'no_search_result_found'		=> __('No search result found!', 'wpfiles'),
			'no_search_result_found_sub'		=> __('Use more generic words or double check your spelling.', 'wpfiles'),
			'no_search_result_found_for'		=> __('No search result found for "%s"', 'wpfiles'),
			'there_are_no_items_here'		=> __('There are no items here!', 'wpfiles'),
			'there_are_no_items_here_sub'		=> __('Start uploading files or folders.', 'wpfiles'),
			'there_are_no_items_here_uncategorized_sub'		=> __('Those files which doesn\'t fall under any category are shown here.', 'wpfiles'),
			'there_are_no_items_here_starred_sub'		=> __('Starred items will be shown here.', 'wpfiles'),
			'trash_bin_is_empty'		=> __('Trash Bin is empty!', 'wpfiles'),
			'trash_bin_is_empty_sub'		=> __('Once you delete an item it will be moved here.', 'wpfiles'),
			'why_you_are_deactivating_your_wpfiles'		=> __('Please leave us feedback on why you are deactivating your WPFiles', 'wpfiles'),
			'does_not_have_features'		=> __('It doesn\'t have features that I want.', 'wpfiles'),
			'plugin_does_not_work'		=> __('Plugin doesn\'t work.', 'wpfiles'),
			'incompatible_with_other_themes_plugins'		=> __('Incompatible with other themes/plugins.', 'wpfiles'),
			'found_another_plugin_that_works_better'		=> __('Found another plugin that works better.', 'wpfiles'),
			'do_not_know_how_to_use_it'		=> __('Don\'t know how to use it.', 'wpfiles'),
			'temporary_deactivation_i_will_use_again'		=> __('Temporary deactivation, I will use again.', 'wpfiles'),
			'other_reason'		=> __('Other reason.', 'wpfiles'),
			'please_select_option'		=> __('Please select a reason for deactivating plugin.', 'wpfiles'),
			'feedback_suggest_a_feature'		=> __('Suggest a Feature', 'wpfiles'),
			'feedback_suggest_a_feature_sub'		=> __('Do you have an idea or suggestion for WPFiles? If you have thoughts on features, integrations, addons, or improvements - we want to hear it! We appreciate all feedback and insight from our users. - <a href="%s" target={"_blank"}>Click here to suggest a feature</a>.', 'wpfiles'),
			'get_help_from_wpfiles_support_team'		=> __('Get help from WPFiles support team', 'wpfiles'),
			'get_help_from_wpfiles_support_team_sub'		=> __('Let our top-notch support team look into the issue and solve it for you asap - <a href="%s" target={"_blank"}>Click here to get help from support team</a>.', 'wpfiles'),
			'with_which_themes_plugins_wpfiles_is_incompatible'		=> __('With which themes/plugins WPFiles is incompatible?', 'wpfiles'),
			'with_which_themes_plugins_wpfiles_is_incompatible_placeholder'		=> __('Enter the name of themes/plugins and incompatibility issue here...', 'wpfiles'),
			'your_name_placeholder'		=> __('Your name...', 'wpfiles'),
			'your_email_placeholder'		=> __('Your email...', 'wpfiles'),
			'your_feedback_placeholder'		=> __('Your feedback...', 'wpfiles'),
			'feedback_explainer'		=> __('We appreciate you taking your time to give feedback. Your feedback is really valuable and helps us to improve WPFiles. Upon feedback submission your contact details (email & name) will be shared as well so if we need more info we can get in touch with you. We will never spam you or sell your email address.', 'wpfiles'),
			'what_is_the_name_of_the_other_plugin'		=> __('What\'s the name of the other plugin?', 'wpfiles'),
			'what_is_the_name_of_the_other_plugin_placeholder'		=> __('Enter the name of the other plugin and in which areas it better than WPFiles here...', 'wpfiles'),
			'we_got_you_all_covered'		=> __('We got you all covered', 'wpfiles'),
			'we_got_you_all_covered_sub'		=> __('Getting used to a new plugin can be tricky sometimes, but don\'t worry to help you better understand WPFiles we got <a href="%1s" target={"_blank"}>helpful docs here</a>, We also have a dedicated <a href="%2s" target={"_blank"}>youtube channel here</a> and a <a href="%3s" target={"_blank"}>private facebook group here</a>.', 'wpfiles'),
			'can_you_please_explain_why_are_you_deactivating_wpfiles'		=> __('Can you please explain why are you deactivating WPFiles?', 'wpfiles'),
			'enter_detail_here_placeholder'		=> __('Enter detail here...', 'wpfiles'),
			'skip_and_deactivate'		=> __('Skip & Deactivate', 'wpfiles'),
			'hey_got_a_minute'		=> __('Hey %s, got a minute?', 'wpfiles'),
			'how_satisfied_are_you'		=> __('How satisfied are you with the WPFiles so far?', 'wpfiles'),
			'bad'		=> __('Bad', 'wpfiles'),
			'poor'		=> __('Poor', 'wpfiles'),
			'average'		=> __('Average', 'wpfiles'),
			'great'		=> __('Great', 'wpfiles'),
			'excellent'		=> __('Excellent', 'wpfiles'),
			'what_do_you_think'		=> __('What do you think we could do to improve WPFiles?', 'wpfiles'),
			'submit_feedback'		=> __('Submit feedback', 'wpfiles'),
			'submit_feedback_after'		=> __('%1s, Thank you for your feedback. If you could rate <b>WPFiles <a href="%2s" target={"_blank"}>&#9733;&#9733;&#9733;&#9733;&#9733;</a></b> on <a href="%2s" target={"_blank"}>WordPress.org</a>, it would be awesome. Your rating will help new users to feel more confident in choosing WPFiles.', 'wpfiles'),
			'leave_a_review_now'		=> __('Leave a review now', 'wpfiles'),
			'we_appreciate_your_help'		=> __('It will hardly take a few minutes. We appreciate your help!', 'wpfiles'),
			'hellobar_upgrade_to_pro'		=> $hellobar_upgrade_to_pro,
			'hellobar_download_pro_version'		=> __('To use Pro modules and features you need to download and install Pro version of WPFiles. <a href="%s" target={"_blank"}>Click here to Download Pro version</a>&#160;<b>&#8594;</b>', 'wpfiles'),
			'hellobar_woocommerce_not_synchronized'		=> __('Your WooCommerce product images are not synchronized yet', 'wpfiles'),
			'hellobar_woocommerce_start_synchronizing_now'		=> __('Start synchronizing now', 'wpfiles'),
			'auto_organize_woocommerce_product_images'		=> __('Auto Organize WooCommerce Product Images', 'wpfiles'),
			'auto_organize_woocommerce_product_images_sub'		=> __('Click on "<b>Start auto organizing</b>" button below to automatically organize existing WooCommerce product images into folders and sub-folders based on categories and sub-categories.', 'wpfiles'),
			'start_auto_organizing'		=> __('Start auto organizing', 'wpfiles'),
			'organizing_in_progress'		=> __('Organizing in progress', 'wpfiles'),
			'organizing_in_progress_sub'		=> __('WooCommerce Products Auto Organizing is in progress, you need to keep this tab open until the process completes.', 'wpfiles'),
			'success_synchronized_woocommerce'		=> __('WPFiles synchronized successfully with your WooCommerce products.', 'wpfiles'),
			'thank_you_for_using_wpfiles'		=> __('Please rate <b>WPFiles <a href="%1s" target={"_blank"}>&#9733;&#9733;&#9733;&#9733;&#9733;</a></b> on <a href="%2s" target={"_blank"}>WordPress.org</a> to help us spread the word. Thank you from the WPFiles team &#9829;', 'wpfiles'),
			'connect_your_account'		=> __('Connect your WPFiles account', 'wpfiles'),
			'something_went_wrong'		=> __('Something went wrong', 'wpfiles'),
			'try_again'		=> __('Try again', 'wpfiles'),
			'upgrade_to_wpfiles_pro'		=> __('Upgrade to WPFiles Pro', 'wpfiles'),
			'hero_section_description_one'		=> $hero_section_description_one,
			'hero_section_description_two'		=> __('Save 2x more with lossy Super-compression and resize huge photos without any size limitations. Use the Woocommerce folders module to automatically organize your media into folders and make folders stand out using colors or starred media & folders module. Get Pro to unlock the true power of WPFiles.', 'wpfiles'),
			'pro_features'		=> __('Pro Features', 'wpfiles'),
			'pro_features_sub'		=> __('Upgrading to WPFiles Pro will get you the following benefits.', 'wpfiles'),
			'wpfiles_cdn_feature'		=> __('WPFiles CDN', 'wpfiles'),
			'wpfiles_cdn_feature_sub'		=> sprintf(__('Get WPFilGet Pro to use WPFiles built-in blazing fast CDN to quickly skyrocket your website speed by optimizing your images on the fly and serving them from over %1$s locations around the globe.', 'wpfiles'), WP_FILES_CDN_POPS),
			'un_restricted_media_library_feature'		=> __('Un-restricted media library', 'wpfiles'),
			'un_restricted_media_library_feature_sub'		=> __('Get Pro to remove all restrictions from the media library on all features such as folder and media sorting, folder uploading, folder search, cut, paste, move to, add to, create shortcuts, and many more...', 'wpfiles'),
			'image_compression_feature_sub'		=> __('Pro unlocks unrestricted one-click bulk compression, Super-compression, PNG to JPEG conversion, Original image compression and lifts the image size limit from %sMB to completely unlimited.', 'wpfiles'),
			'image_watermark_feature_sub'		=> __('Pro unlocks full control over your watermark size, position and opacity settings through a simple and intuitive interface.', 'wpfiles'),
			'media_download_feature_sub'		=> __('With Pro you can download all the items from your media library or just the ones that you want. Selected items will be zipped and start downloading instantly.', 'wpfiles'),
			'folders_color_feature_sub'		=> __('Use Pro to make your folders stand out from the crowd by applying colors to them. Because different folders will be used for different purposes.', 'wpfiles'),
			'starred_media_folder_feature_sub'		=> __('Starring is a way to bookmark your important media or folders. Pro allows you to use this module to quickly access your most important media or folders at all times.', 'wpfiles'),
			'woocommerce_folders_feature_sub'		=> __('Use Pro to organize all of your WooCommerce product images into folders automatically created on basis of products, categories, and more...', 'wpfiles'),
			'third_party_compatibility_feature_sub'		=> __('Get Pro to directly integrate WPFiles into over 20+ plugins and themes. This means that you can now have WPFiles media library management everywhere.', 'wpfiles'),
			'gutenberg_gallery_feature_sub'		=> __('With Pro you can create dynamic galleries from a folder. Show images in columns, set the maximum number of images per column, choose the layout, and much more.', 'wpfiles'),
			'and_more_features'		=> __('And many many more...', 'wpfiles'),
			'and_more_features_sub'		=> __('Click here to see a complete list of all the Pro features that WPFiles has to offer.', 'wpfiles'),
			'empowering_thousands_of_websites'		=> __('Empowering thousands of websites from all over the world', 'wpfiles'),
			'number_millions'		=> __('%s Million', 'wpfiles'),
			'images_optimized'		=> __('Images Optimized', 'wpfiles'),
			'websites_optimized'		=> __('Websites Optimized', 'wpfiles'),
			'monthly_cdn_bandwidth'		=> __('Monthly CDN Bandwidth', 'wpfiles'),
			'active_users'		=> __('Active Users', 'wpfiles'),
			'customer_review_1'		=> __('The plugin is extremely useful for managing the WordPress Media library. Additionally, WPFiles CDN is a great way to speed up your website and make it load faster with just a few clicks. I highly recommend using WPFiles for all of your media management and website speed optimization needs.', 'wpfiles'),
			'customer_review_2'		=> __('Almost anyone can make a plugin, but few can make a great one like this, and almost no one achieves the level of excellence reached by WPFiles Team! They not only provide quality plugins, at affordable prices, with good update policies, but they back it all up with real people offering friendly and helpful support.', 'wpfiles'),
			'customer_review_3'		=> __('WPFiles Pro is a must-have WordPress plugin that every web developer, designer and publisher should have in their arsenal. The fact that you can use it as a lite plugin or choose PRO features make WPFiles Pro incredibly versatile.', 'wpfiles'),
			'get_started_with_wpfiles_pro_today'		=> __('Get started with WPFiles Pro today', 'wpfiles'),
			'get_started_with_wpfiles_pro_today_sub'		=> __('%s of customers are happy with WPFiles Pro, and thinks it\'s worth every penny as a WPFiles user you\’ll get a free trial, so you can see what all the fuss is about.', 'wpfiles'),
			'joyride_modal_title'		=> __('Thank you for installing WPFiles', 'wpfiles'),
			'joyride_modal_sub'		=> __('We have a small tour for you to help better understand WPFiles and to unleash its true power. It will hardly take a minute to complete.We highly recommend you to take this tour.', 'wpfiles'),
			'joyride_modal_action'		=> __('Lets start', 'wpfiles'),
			'joyride_next'		=> __('Next', 'wpfiles'),
			'joyride_last'		=> __('Last', 'wpfiles'),
			'joyride_step_add_new_title'		=> __('Upload new files or folders', 'wpfiles'),
			'joyride_step_add_new_content'		=> __('Use this button to upload files from your computer or to create a new folder.<br />You can also drag and drop files and folders into the media library.', 'wpfiles'),
			'joyride_step_all_files_title'		=> __('All Files', 'wpfiles'),
			'joyride_step_all_files_content'		=> __('All Files will be shown inside this root folder irrespective of their actual location in media library.', 'wpfiles'),
			'joyride_step_uncategorized_title'		=> __('Uncategorized', 'wpfiles'),
			'joyride_step_uncategorized_content'		=> __('Media items which are not attached to any folder will be shown here.', 'wpfiles'),
			'joyride_step_folders_tree_title'		=> __('Folders Tree', 'wpfiles'),
			'joyride_step_folders_tree_content'		=> __('Any folder you create will be shown here.<br />You can also drag and drop files directly into these folders.', 'wpfiles'),
			'joyride_step_footer_actions_title'		=> __('Compression and Watermarking', 'wpfiles'),
			'joyride_step_footer_actions_content'		=> __('Use these button to bulk compress or watermark images.<br />You can also do directory compression and watermarking.', 'wpfiles'),
			'joyride_step_grid_list_title'		=> __('Grid and List View', 'wpfiles'),
			'joyride_step_grid_list_content'		=> __('Use these buttons to switch between grid and list view.', 'wpfiles'),
			'joyride_step_search_media_filter_title'		=> __('Media searching and filtering', 'wpfiles'),
			'joyride_step_search_media_filter_content'		=> __('You can search for files and folders using this search box. Also, you can apply filters or bulk select items using the filter button.', 'wpfiles'),
			'joyride_step_media_items_title'		=> __('Files and Folders', 'wpfiles'),
			'joyride_step_media_items_content'		=> __('<div>All media items will be shown here for selected folder along with sub-folders if there are any.<br />To bulk-select items try dragging mouse while holding the click from one corner.</div>', 'wpfiles'),
			'joyride_step_last'		=> __('<h2>Thats all for now, Have fun!</h2>Some final tips for you:<ul> <li>Drag your mouse from the one corner while holding the click to bulk select items.</li><li>Right click on any file or folder to see more options.</li> <li>Use bulk-bar to perform bulk actions on selected items.</li><li>Use the <strong>Modules</strong> section to manage all modules.</li><li>Use the <strong>Settings</strong> section to configure the plugin.</li></ul>', 'wpfiles'),
		);

		return $translation;
    }

	/**
	 * getProTranslations
	 * @since    1.0.0
	 * @return array
	 */
	public static function getProTranslations()
    {
		$translation = array(
			'folders_color_updated' => __('%1$s folders color updated.', 'wpfiles'),
			'folder_color_updated' => __('"%1$s" color updated.', 'wpfiles'),
			'items_were_added_to_starred' => __('%1$s items were added to starred.', 'wpfiles'),
			'items_were_removed_from_starred' => __('%1$s items were removed from starred.', 'wpfiles'),
			'item_was_added_to_starred' => __('"%1$s" was added to starred.', 'wpfiles'),
			'item_was_removed_from_starred' => __('"%1$s" was removed from starred.', 'wpfiles'),
			'single_item_was_added_to_starred' => __('1 item was added to starred.', 'wpfiles'),
			'single_item_was_removed_from_starred' => __('1 item was removed from starred.', 'wpfiles'),
			'connect_account_pro_notice_msg' =>  __('Thanks for installing WPFiles Pro! Please connect your account to use all Pro features/modules and to keep your WPFiles Pro up-to-date. %1$sClick here to connect%2$s your account.', 'wpfiles'),
			'connect_account_free_notice_msg' =>  __('Thanks for installing WPFiles! You need to connect you website with your WPFiles account in order to use some of the features such as Image Compression. If you aren’t already registered %1$sclick here to register now%2$s, it’s free.', 'wpfiles'),
			'some_general_error_msg' => __('Some error occurred, please try again', 'wpfiles'),
		);

		return $translation;
	}

}